import { decorateProperty } from './base.js';

/**
 * @license
 * Copyright 2017 Google LLC
 * SPDX-License-Identifier: BSD-3-Clause
 */
/**
 * A property decorator that converts a class property into a getter that
 * executes a querySelector on the element's renderRoot.
 *
 * @param selector A DOMString containing one or more selectors to match.
 * @param cache An optional boolean which when true performs the DOM query only
 *     once and caches the result.
 *
 * See: https://developer.mozilla.org/en-US/docs/Web/API/Document/querySelector
 *
 * ```ts
 * class MyElement {
 *   @query('#first')
 *   first: HTMLDivElement;
 *
 *   render() {
 *     return html`
 *       <div id="first"></div>
 *       <div id="second"></div>
 *     `;
 *   }
 * }
 * ```
 * @category Decorator
 */
function query(selector, cache) {
    return decorateProperty({
        descriptor: (name) => {
            const descriptor = {
                get() {
                    return this.renderRoot?.querySelector(selector) ?? null;
                },
                enumerable: true,
                configurable: true,
            };
            if (cache) {
                const key = Symbol(`${String(name)} (@query() cache)`)
                    ;
                descriptor.get = function () {
                    if (this[key] ===
                        undefined) {
                        this[key] =
                            this.renderRoot?.querySelector(selector) ?? null;
                    }
                    return this[key];
                };
            }
            return descriptor;
        },
    });
}

export { query };
//# sourceMappingURL=query.js.map
